@@ -1,5 +1,6 @@
 import asyncio
 import logging
+import os
 from typing import Dict, List
 
 import httpx
@@ -12,9 +13,10 @@ logger = logging.getLogger(__name__)
 
 public_keys = {}
 
-# endpoint for getting all enabled JWKs
-base_url = get_config("keycloak.base_url") or "https://auth.delphai.com"
-url = f"{base_url}/auth/realms/delphai/protocol/openid-connect/certs"
+# base URL of the OIDC provider
+OIDC_BASE_URL = os.getenv(
+    "OIDC_BASE_URL", "https://auth.delphai.com/auth/realms/delphai"
+)
 
 
 async def decode_token(access_token: str) -> str:
@@ -34,6 +36,8 @@ class PublicKeyFetchError(Exception):
 async def __async_fetch_keys() -> List[Dict]:
     global public_keys
     async with httpx.AsyncClient() as client:
+        # endpoint for getting all enabled JWKs
+        url = f"{OIDC_BASE_URL}/protocol/openid-connect/certs"
         response = await client.get(url)
         if response.status_code != 200:
             print("failed")
@@ -48,6 +52,6 @@ async def update_public_keys(interval: int = 60 * 10):  # updates every 10 minut
     while True:
         try:
             await __async_fetch_keys()
-        except PublicKeyFetchError:
-            logger.exception("Error fetching jwk from keycloak")
+        except (httpx.HTTPError, PublicKeyFetchError):
+            logger.exception("Error fetching JWK from Keycloak")
         await asyncio.sleep(interval)
